import leapp.libraries.actor.checkoldxfs as checkoldxfs
from leapp.actors import Actor
from leapp.models import XFSInfoFacts
from leapp.reporting import Report
from leapp.tags import ChecksPhaseTag, IPUWorkflowTag


class CheckOldXFS(Actor):
    """
    Inhibit upgrade if XFS requirements for RHEL 10 are not satisfied.

    RHEL 10 introduces stricter requirements for XFS filesystems. If any XFS
    filesystem on the system lack these required features, the upgrade will be
    inhibited:
      - XFS format v5 (CRC=1 is good indicator)
      - bigtime=1 (longer size of timestamp, covering Y2K38 to be able to
        represent time after 2038-01-19)

    """

    name = 'check_old_xfs'
    consumes = (XFSInfoFacts,)
    produces = (Report,)
    tags = (ChecksPhaseTag, IPUWorkflowTag,)

    def process(self):
        checkoldxfs.process()
